@@ -1,22 +1,9 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 1999 Waldo Bastian (bastian@kde.org)
+/*  This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 Waldo Bastian <bastian@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
-//-----------------------------------------------------------------------------
+
 // KDE color collection
 
 #include "kcolorcollection.h"
@@ -78,7 +65,7 @@ KColorCollectionPrivate::KColorCollectionPrivate(const QString &_name)
         line = QString::fromLocal8Bit(paletteFile.readLine());
         if (line[0] == QLatin1Char('#')) {
             // This is a comment line
-            line = line.mid(1); // Strip '#'
+            line.remove(0, 1); // Strip '#'
             line = line.trimmed(); // Strip remaining white space..
             if (!line.isEmpty()) {
                 desc += line + QLatin1Char('\n'); // Add comment to description
@@ -152,11 +139,15 @@ KColorCollection::save()
     QTextStream str(&sf);
 
     QString description = d->desc.trimmed();
-    description = QLatin1Char('#') + description.split(QLatin1Char('\n'), QString::KeepEmptyParts).join(QStringLiteral("\n#"));
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+    description = QLatin1Char('#') + description.split(QLatin1Char('\n'), QString::KeepEmptyParts).join(QLatin1String("\n#"));
+#else
+    description = QLatin1Char('#') + description.split(QLatin1Char('\n'), Qt::KeepEmptyParts).join(QLatin1String("\n#"));
+#endif
 
     str << QLatin1String("KDE RGB Palette\n");
     str << description << QLatin1Char('\n');
-    foreach (const KColorCollectionPrivate::ColorNode &node, d->colorList) {
+    for (const KColorCollectionPrivate::ColorNode &node : qAsConst(d->colorList)) {
         int r, g, b;
         node.color.getRgb(&r, &g, &b);
         str << r << " " << g << " " << b << " " << node.name << "\n";
